pub enum CustomCursorTemplate {
Image(<CustomCursorImage as FromTemplate>::Template),
Url(<CustomCursorUrl as FromTemplate>::Template),
}Variants
Image(<CustomCursorImage as FromTemplate>::Template)
Url(<CustomCursorUrl as FromTemplate>::Template)
Implementations
Sourceimpl CustomCursorTemplate
impl CustomCursorTemplate
Sourcepub fn default_image() -> Self
pub fn default_image() -> Self
Default value for this variant, generated by a FromTemplate derive.
Sourcepub fn default_url() -> Self
pub fn default_url() -> Self
Default value for this variant, generated by a FromTemplate derive.